@@ -165,7 +165,7 @@ def load_visual_graph_element(path: str,
     element_data = {}
 
     metadata_path = os.path.join(path, f'{name}.json')
-    with open(metadata_path, file='r') as file:
+    with open(metadata_path, mode='r') as file:
         content = file.read()
         metadata = json.loads(content)
 
