@@ -359,6 +359,8 @@ class MoleculeProcessing(ProcessingBase):
                double_edges_undirected: bool = True,
                use_node_coordinates: bool = False,
                graph_labels: list = [],
+               additional_metadata: dict = {},
+               additional_graph_data: dict = {},
                width: int = 1000,
                height: int = 1000,
                create_svg: bool = False,
@@ -382,6 +384,10 @@ class MoleculeProcessing(ProcessingBase):
             use_node_coordinates=use_node_coordinates,
             graph_labels=graph_labels,
         )
+        g.update({
+            'graph_labels': graph_labels,
+            **additional_graph_data,
+        })
         fig, node_positions, svg_string = self.visualize_as_figure(
             smiles=smiles,
             width=width,
@@ -397,11 +403,12 @@ class MoleculeProcessing(ProcessingBase):
         plt.close(fig)
 
         metadata = {
-            'index': int(index),
-            'name': name,
-            'smiles': smiles,
-            'target': graph_labels,
-            'graph': g
+            'index':    int(index),
+            'name':     name,
+            'smiles':   smiles,
+            'target':   graph_labels,
+            'graph':    g,
+            **additional_metadata,
         }
         metadata_path = os.path.join(output_path, f'{index}.json')
         self.save_metadata(metadata, metadata_path)
