@@ -1,3 +1,6 @@
+"""
+Functionality to support unittests.
+"""
 import os
 import tempfile
 import typing as t
@@ -6,6 +9,16 @@ from visual_graph_datasets.util import TEMPLATE_ENV
 from visual_graph_datasets.config import Config
 
 
+def clear_files(file_paths: t.List[str]):
+    """
+    Small utility function, which will make sure that all the files with the given ``file_paths`` are
+    definitely removed from the filesystem. Used for testing purposes.
+    """
+    for file_path in file_paths:
+        if os.path.exists(file_path) and os.path.isfile(file_path):
+            os.remove(file_path)
+
+
 class IsolatedConfig:
     """
     This is a context manager which will create a fresh config file from the default template within
