@@ -31,10 +31,18 @@ def create_frameless_figure(width: int = 100,
         size of the image.
     :return:
     """
-    fig, ax = plt.subplots(nrows=1, ncols=1, figsize=(width / (100 * ratio), height / (100 * ratio)))
+    fig, ax = plt.subplots(
+        nrows=1,
+        ncols=1,
+        figsize=(width / (100 * ratio), height / (100 * ratio)),
+        frameon=False,
+    )
     fig.set_dpi(100 * ratio)
 
     # https://stackoverflow.com/questions/14908576
+    ax.get_xaxis().set_ticks([])
+    ax.get_yaxis().set_ticks([])
+
     ax.spines['top'].set_visible(False)
     ax.spines['right'].set_visible(False)
     ax.spines['bottom'].set_visible(False)
@@ -51,7 +59,10 @@ def create_frameless_figure(width: int = 100,
 
     # https://stackoverflow.com/questions/4581504
     fig.patch.set_facecolor((0, 0, 0, 0))
+    fig.patch.set_visible(False)
+
     ax.patch.set_facecolor((0, 0, 0, 0))
+    ax.patch.set_visible(False)
 
     # A big part of achieving the effect we desire here, that is having only the Axes show up in the final
     # file and none of the border or padding of the Figure, is which arguments are passed to the "savefig"
@@ -67,7 +78,18 @@ def create_frameless_figure(width: int = 100,
 
 
 def layout_node_positions(g: tc.GraphDict,
-                          layout_cb: t.Callable = nx.spring_layout):
+                          layout_cb: t.Callable[[nx.Graph], dict] = nx.spring_layout
+                          ) -> np.ndarray:
+    """
+    Given a GraphDict ``g`` this method will create 2D positions for each of the nodes of the graph using
+    the networkx layout function given as ``layout_cb``.
+
+    :param g: A GraphDict representation of a graph
+    :param layout_cb: A callable which accepts a networkx.Graph instance and returns a position dictionary.
+        This description fits for all networkx "layout" functions.
+
+    :returns: A numpy array of graph node positions in a 2D plane with shape (num_nodes, 2)
+    """
     # We will use "networkx" to actually execute the layouting algorithms for the graph.
     # To do this however we first need to convert the graph which is currently a GraphDict into a networkx
     # Graph object.
