@@ -1,5 +1,6 @@
 import typing as t
 
+import networkx as nx
 import numpy as np
 import matplotlib as mpl
 import matplotlib.pyplot as plt
@@ -7,6 +8,25 @@ import matplotlib.pyplot as plt
 import visual_graph_datasets.typing as tc
 
 
+def colors_layout(G, k: float = 1, scale: float = 10.0):
+    pos = None
+    pos = nx.spring_layout(
+        G,
+        pos=pos,
+        iterations=100,
+        threshold=1e-3,
+        k=k,
+        scale=scale,
+        center=[0, 0]
+    )
+    pos = nx.kamada_kawai_layout(
+        G,
+        pos=pos,
+        scale=scale,
+    )
+    return pos
+
+
 def visualize_grayscale_graph(ax: plt.Axes,
                               g: tc.GraphDict,
                               node_positions: np.ndarray,
@@ -117,3 +137,10 @@ def visualize_color_graph(ax: plt.Axes,
             lw=edge_width,
             zorder=1,
         )
+
+    # 23.03.2023 - Now this is wild...
+    # What we do here is we plot a completely transparent marker on top of every node, which functionally
+    # has absolutely no effect because it's completely transparent. BUT, this is actually necessary for some
+    # reason to prevent the position-drifting bug!
+    for (x, y) in node_positions:
+        ax.scatter(x, y, color=(1, 1, 1, 0), marker='x', s=100, zorder=3)
