@@ -85,6 +85,8 @@ def create_importances_pdf(graph_list: t.List[tc.GraphDict],
                            plot_edge_importances_cb: t.Callable = plot_edge_importances_border,
                            base_fig_size: float = 8,
                            normalize_importances: bool = True,
+                           show_x_ticks: bool = False,
+                           show_y_ticks: bool = False,
                            logger: logging.Logger = NULL_LOGGER,
                            log_step: int = 100,
                            ):
@@ -180,8 +182,10 @@ def create_importances_pdf(graph_list: t.List[tc.GraphDict],
                         image,
                         extent=extent
                     )
-                    ax.set_xticks([])
-                    ax.set_yticks([])
+                    if not show_x_ticks:
+                        ax.set_xticks([])
+                    if not show_y_ticks:
+                        ax.set_yticks([])
 
                     if normalize_importances:
                         node_v_max = np.max(node_importances)
